.. image:: https://img.shields.io/pypi/v/twine.svg
   :target: https://pypi.org/project/twine

.. image:: https://img.shields.io/pypi/pyversions/twine.svg
   :target: https://pypi.org/project/twine

.. image:: https://img.shields.io/readthedocs/twine
   :target: https://twine.readthedocs.io

.. image:: https://img.shields.io/github/workflow/status/pypa/twine/Main
   :target: https://github.com/pypa/twine/actions

.. image:: https://img.shields.io/codecov/c/github/pypa/twine
   :target: https://codecov.io/gh/pypa/twine

twine
=====

Twine is a utility for `publishing`_ Python packages on `PyPI`_.

It provides build system independent uploads of source and binary
`distribution artifacts <distributions_>`_ for both new and existing
`projects`_.

See our `documentation`_ for a description of features, installation
and usage instructions, and links to additional resources.

Contributing
------------

See our `developer documentation`_ for how to get started, an
architectural overview, and our future development plans.

Code of Conduct
---------------

Everyone interacting in the Twine project's codebases, issue
trackers, chat rooms, and mailing lists is expected to follow the
`PSF Code of Conduct`_.

.. _`publishing`: https://packaging.python.org/tutorials/distributing-packages/
.. _`PyPI`: https://pypi.org
.. _`distributions`:
   https://packaging.python.org/glossary/#term-Distribution-Package
.. _`projects`: https://packaging.python.org/glossary/#term-Project
.. _`documentation`: https://twine.readthedocs.io/
.. _`developer documentation`:
   https://twine.readthedocs.io/en/latest/contributing.html
.. _`PSF Code of Conduct`: https://github.com/pypa/.github/blob/main/CODE_OF_CONDUCT.md
